function ret = ecopula(X,varargin)
% This function calculates the empirical copula values for multivariate 
% data X.
%
% call: ret = ecopula(X[,Y])
%
% input     X               - nxp data matrix with n observations over p
%                             dimensions, for which the empirical copula  
%                             value is calculated
%           Y (optional)    - mxp data matrix, on which the empirical 
%                             copula is based
%
% output    ret             - the empirical copula values for data X
%
% Author: Maximilian Coblenz, 2017
% This code is released under the 3-clause BSD license.
% 

[n,p] = size(X);

if nargin == 2
    Y = varargin{1};
    m = size(Y,1);
else
    Y = X;
    m = n;
end

Fn = zeros(n,1);

for ii = 1:1:n

    Fn(ii) = sum(all(reshape(Y<=repmat(X(ii,:),m,1),m,p),2))/(m+1);
    
end

ret = Fn;

end